@@ -2,9 +2,9 @@ package MooseX::Constructor::AllErrors;
 BEGIN {
   $MooseX::Constructor::AllErrors::AUTHORITY = 'cpan:HDP';
 }
-# git description: v0.022-2-gaf92436
-$MooseX::Constructor::AllErrors::VERSION = '0.023';
-# ABSTRACT: capture all constructor errors
+# git description: v0.023-7-g1944d11
+$MooseX::Constructor::AllErrors::VERSION = '0.024';
+# ABSTRACT: Capture all constructor errors
 
 use Moose ();
 use Moose::Exporter;
@@ -27,13 +27,15 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Hans Dieter Pearcey Jesse Luehrs Karen Etheridge Shawn Sorichetti
+
 =head1 NAME
 
-MooseX::Constructor::AllErrors - capture all constructor errors
+MooseX::Constructor::AllErrors - Capture all constructor errors
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -72,4 +74,26 @@ This software is copyright (c) 2009 by Hans Dieter Pearcey.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Shawn Sorichetti <ssoriche@gmail.com>
+
+=back
+
 =cut
